@@ -79,7 +79,7 @@ typedef Eo Efl_Io_Copier;
  */
 #define EFL_IO_COPIER_CLASS efl_io_copier_class_get()
 
-EWAPI const Efl_Class *efl_io_copier_class_get(void);
+EWAPI const Efl_Class *efl_io_copier_class_get(void) EINA_CONST;
 
 /**
  * @brief Copier source object.
@@ -211,9 +211,9 @@ EOAPI Efl_Io_Reader *efl_io_copier_source_get(const Eo *obj);
  * the destination then the "done" event is emitted.
  *
  * If the destination is not set (ie: @c NULL) then data is kept in a internal
- * @ref Eina_Binbuf, which can be stolen with @ref efl_io_copier_binbuf_steal
- * once "data" or "line" events are emitted. It exists as a useful shortcut to
- * easily drain readers and store all data in memory with no need to use an
+ * binbuf, which can be stolen with @ref efl_io_copier_binbuf_steal once "data"
+ * or "line" events are emitted. It exists as a useful shortcut to easily drain
+ * readers and store all data in memory with no need to use an
  * @ref Efl_Io_Buffer or @ref Efl_Io_Copier  -- a source and copier are enough.
  *
  * If both source and destination object implements @ref Efl_Io_Sizer, then the
@@ -261,9 +261,9 @@ EOAPI void efl_io_copier_destination_set(Eo *obj, Efl_Io_Writer *destination);
  * the destination then the "done" event is emitted.
  *
  * If the destination is not set (ie: @c NULL) then data is kept in a internal
- * @ref Eina_Binbuf, which can be stolen with @ref efl_io_copier_binbuf_steal
- * once "data" or "line" events are emitted. It exists as a useful shortcut to
- * easily drain readers and store all data in memory with no need to use an
+ * binbuf, which can be stolen with @ref efl_io_copier_binbuf_steal once "data"
+ * or "line" events are emitted. It exists as a useful shortcut to easily drain
+ * readers and store all data in memory with no need to use an
  * @ref Efl_Io_Buffer or @ref Efl_Io_Copier  -- a source and copier are enough.
  *
  * If both source and destination object implements @ref Efl_Io_Sizer, then the
