@@ -13,24 +13,22 @@ typedef Eo Efl_Io_Reader_Fd;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Reads fd using read(2).
- *
- * @since 1.19
  *
  * @ingroup Efl_Io_Reader_Fd
  */
 #define EFL_IO_READER_FD_MIXIN efl_io_reader_fd_mixin_get()
 
-EWAPI const Efl_Class *efl_io_reader_fd_mixin_get(void);
+EWAPI const Efl_Class *efl_io_reader_fd_mixin_get(void) EINA_CONST;
 
 #ifdef EFL_IO_READER_FD_PROTECTED
 /**
  * @brief Reader file descriptor
  *
+ * @param[in] obj The object.
  * @param[in] fd File descriptor
  *
- * @since 1.19
- *
  * @ingroup Efl_Io_Reader_Fd
  */
 EOAPI void efl_io_reader_fd_set(Eo *obj, int fd);
@@ -39,12 +37,13 @@ EOAPI void efl_io_reader_fd_set(Eo *obj, int fd);
 /**
  * @brief Reader file descriptor
  *
- * @return File descriptor
+ * @param[in] obj The object.
  *
- * @since 1.19
+ * @return File descriptor
  *
  * @ingroup Efl_Io_Reader_Fd
  */
 EOAPI int efl_io_reader_fd_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
