@@ -24,7 +24,7 @@ typedef Eo Efl_Loop_Consumer;
  */
 #define EFL_LOOP_CONSUMER_CLASS efl_loop_consumer_class_get()
 
-EWAPI const Efl_Class *efl_loop_consumer_class_get(void);
+EWAPI const Efl_Class *efl_loop_consumer_class_get(void) EINA_CONST;
 
 /**
  * @brief Handle of the loop this object belongs to.
