@@ -13,13 +13,14 @@ typedef Eo Ecore_Audio_Out;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Ecore Audio output object.
  *
  * @ingroup Ecore_Audio_Out
  */
 #define ECORE_AUDIO_OUT_CLASS ecore_audio_out_class_get()
 
-EWAPI const Efl_Class *ecore_audio_out_class_get(void);
+EWAPI const Efl_Class *ecore_audio_out_class_get(void) EINA_CONST;
 
 /**
  * @brief Attaches an input to an output
@@ -29,8 +30,6 @@ EWAPI const Efl_Class *ecore_audio_out_class_get(void);
  *
  * @return @c true if the input was attached, @c false otherwise
  *
- * @since 1.8
- *
  * @ingroup Ecore_Audio_Out
  */
 EOAPI Eina_Bool ecore_audio_obj_out_input_attach(Eo *obj, Ecore_Audio_In *input);
@@ -43,8 +42,6 @@ EOAPI Eina_Bool ecore_audio_obj_out_input_attach(Eo *obj, Ecore_Audio_In *input)
  *
  * @return @c true if the input was detached, @c false otherwise
  *
- * @since 1.8
- *
  * @ingroup Ecore_Audio_Out
  */
 EOAPI Eina_Bool ecore_audio_obj_out_input_detach(Eo *obj, Ecore_Audio_In *input);
@@ -56,10 +53,9 @@ EOAPI Eina_Bool ecore_audio_obj_out_input_detach(Eo *obj, Ecore_Audio_In *input)
  *
  * @return A list of the inputs that are attached to the output
  *
- * @since 1.8
- *
  * @ingroup Ecore_Audio_Out
  */
 EOAPI Eina_List *ecore_audio_obj_out_inputs_get(Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
