@@ -20,7 +20,7 @@ typedef Eo Efl_Net_Server_Ssl;
  */
 #define EFL_NET_SERVER_SSL_CLASS efl_net_server_ssl_class_get()
 
-EWAPI const Efl_Class *efl_net_server_ssl_class_get(void);
+EWAPI const Efl_Class *efl_net_server_ssl_class_get(void) EINA_CONST;
 
 /**
  * @brief Defines the SSL context to use for this server.
