@@ -13,19 +13,18 @@ typedef Eo Efl_Net_Socket_Tcp;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief A base TCP socket.
  *
  * This is the common class and takes an existing FD, usually created by an
  * dialer or server.
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Tcp
  */
 #define EFL_NET_SOCKET_TCP_CLASS efl_net_socket_tcp_class_get()
 
-EWAPI const Efl_Class *efl_net_socket_tcp_class_get(void);
+EWAPI const Efl_Class *efl_net_socket_tcp_class_get(void) EINA_CONST;
 
 /**
  * @brief Controls keep-alive using SO_KEEPALIVE
@@ -35,8 +34,6 @@ EWAPI const Efl_Class *efl_net_socket_tcp_class_get(void);
  *
  * @return @c true on success
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Tcp
  */
 EOAPI Eina_Bool efl_net_socket_tcp_keep_alive_set(Eo *obj, Eina_Bool keep_alive);
@@ -48,8 +45,6 @@ EOAPI Eina_Bool efl_net_socket_tcp_keep_alive_set(Eo *obj, Eina_Bool keep_alive)
  *
  * @return @c true if keep alive is enabled, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Tcp
  */
 EOAPI Eina_Bool efl_net_socket_tcp_keep_alive_get(const Eo *obj);
@@ -62,8 +57,6 @@ EOAPI Eina_Bool efl_net_socket_tcp_keep_alive_get(const Eo *obj);
  *
  * @return @c true on success
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Tcp
  */
 EOAPI Eina_Bool efl_net_socket_tcp_no_delay_set(Eo *obj, Eina_Bool no_delay);
@@ -75,8 +68,6 @@ EOAPI Eina_Bool efl_net_socket_tcp_no_delay_set(Eo *obj, Eina_Bool no_delay);
  *
  * @return @c true if no delay is enabled, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Tcp
  */
 EOAPI Eina_Bool efl_net_socket_tcp_no_delay_get(const Eo *obj);
@@ -89,8 +80,6 @@ EOAPI Eina_Bool efl_net_socket_tcp_no_delay_get(const Eo *obj);
  *
  * @return @c true on success
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Tcp
  */
 EOAPI Eina_Bool efl_net_socket_tcp_cork_set(Eo *obj, Eina_Bool cork);
@@ -102,10 +91,9 @@ EOAPI Eina_Bool efl_net_socket_tcp_cork_set(Eo *obj, Eina_Bool cork);
  *
  * @return @c true if cork is enabled, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Socket_Tcp
  */
 EOAPI Eina_Bool efl_net_socket_tcp_cork_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
