@@ -26,13 +26,13 @@ typedef Eo Efl_Io_Reader;
  * "can_read,changed" or property @ref efl_io_reader_can_read_get to known
  * whenever a read would have data to return.
  *
- * @since 1.19
+ * @since 1.22
  *
  * @ingroup Efl_Io_Reader
  */
 #define EFL_IO_READER_INTERFACE efl_io_reader_interface_get()
 
-EWAPI const Efl_Class *efl_io_reader_interface_get(void);
+EWAPI const Efl_Class *efl_io_reader_interface_get(void) EINA_CONST;
 
 /**
  * @brief Reads data into a pre-allocated buffer.
@@ -51,11 +51,11 @@ EWAPI const Efl_Class *efl_io_reader_interface_get(void);
  *
  * @return 0 on succeed, a mapping of errno otherwise
  *
- * @since 1.19
+ * @since 1.22
  *
  * @ingroup Efl_Io_Reader
  */
-EOAPI Eina_Error efl_io_reader_read(Eo *obj, Eina_Rw_Slice *rw_slice) EINA_ARG_NONNULL(2);
+EOAPI Eina_Error efl_io_reader_read(Eo *obj, Eina_Rw_Slice *rw_slice);
 
 #ifdef EFL_IO_READER_PROTECTED
 /**
@@ -66,7 +66,7 @@ EOAPI Eina_Error efl_io_reader_read(Eo *obj, Eina_Rw_Slice *rw_slice) EINA_ARG_N
  * @param[in] can_read @c true if it can be read without blocking or failing,
  * @c false otherwise
  *
- * @since 1.19
+ * @since 1.22
  *
  * @ingroup Efl_Io_Reader
  */
@@ -82,7 +82,7 @@ EOAPI void efl_io_reader_can_read_set(Eo *obj, Eina_Bool can_read);
  * @return @c true if it can be read without blocking or failing, @c false
  * otherwise
  *
- * @since 1.19
+ * @since 1.22
  *
  * @ingroup Efl_Io_Reader
  */
@@ -95,7 +95,7 @@ EOAPI Eina_Bool efl_io_reader_can_read_get(const Eo *obj);
  * @param[in] obj The object.
  * @param[in] is_eos @c true if end of stream, @c false otherwise
  *
- * @since 1.19
+ * @since 1.22
  *
  * @ingroup Efl_Io_Reader
  */
@@ -109,7 +109,7 @@ EOAPI void efl_io_reader_eos_set(Eo *obj, Eina_Bool is_eos);
  *
  * @return @c true if end of stream, @c false otherwise
  *
- * @since 1.19
+ * @since 1.22
  *
  * @ingroup Efl_Io_Reader
  */
@@ -128,7 +128,9 @@ EWAPI extern const Efl_Event_Description _EFL_IO_READER_EVENT_CAN_READ_CHANGED;
  * Note that usually this event is dispatched from inside
  * @ref efl_io_reader_read, thus before it returns.
  *
- * @since 1.19
+ * @return Eina_Bool
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Io_Reader
  */
@@ -148,7 +150,7 @@ EWAPI extern const Efl_Event_Description _EFL_IO_READER_EVENT_EOS;
  * The property @ref efl_io_reader_can_read_get should change to @c false
  * before this event is dispatched.
  *
- * @since 1.19
+ * @since 1.22
  *
  * @ingroup Efl_Io_Reader
  */
