@@ -25,7 +25,7 @@ typedef Eo Efl_Pack_Linear;
  */
 #define EFL_PACK_LINEAR_INTERFACE efl_pack_linear_interface_get()
 
-EWAPI const Efl_Class *efl_pack_linear_interface_get(void);
+EWAPI const Efl_Class *efl_pack_linear_interface_get(void) EINA_CONST;
 
 /**
  * @brief Prepend an object at the beginning of this container.
