@@ -21,7 +21,8 @@ typedef Eo Efl_Part;
  * widget's theme.
  *
  * Part proxy objects have a special lifetime that is limited to one and only
- * one function call.
+ * one function call. This behavior is implemented in efl_part() which call
+ * @ref efl_part_get(). Calling @ref efl_part_get() directly should be avoided.
  *
  * In other words, the caller does not hold a reference to this proxy object.
  * It may be possible, in languages that allow it, to get an extra reference to
@@ -37,23 +38,28 @@ typedef Eo Efl_Part;
  * part = ref(part(obj, "part")) func1(part, args) func2(part, args)
  * func3(part, args) unref(part)
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Part
  */
 #define EFL_PART_INTERFACE efl_part_interface_get()
 
-EWAPI const Efl_Class *efl_part_interface_get(void);
+EWAPI const Efl_Class *efl_part_interface_get(void) EINA_CONST;
 
+#ifdef EFL_PART_PROTECTED
 /**
  * @brief Get a proxy object referring to a part of an object.
  *
- * The returned object is valid for only a single function call.
- *
+ * @param[in] obj The object.
  * @param[in] name The part name.
  *
  * @return A (proxy) object, valid for a single call.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Part
  */
-EOAPI Efl_Object *efl_part(const Eo *obj, const char *name);
+EOAPI Efl_Object *efl_part_get(const Eo *obj, const char *name);
+#endif
 
 #endif
