@@ -13,25 +13,36 @@ typedef Eo Eldbus_Model_Method;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Eldbus model method class
  *
  * @ingroup Eldbus_Model_Method
  */
 #define ELDBUS_MODEL_METHOD_CLASS eldbus_model_method_class_get()
 
-EWAPI const Efl_Class *eldbus_model_method_class_get(void);
+EWAPI const Efl_Class *eldbus_model_method_class_get(void) EINA_CONST;
 
 /**
  * @brief Custom Eldbus_Model_Method constructor.
  *
+ * @param[in] obj The object.
  * @param[in] proxy Eldbus proxy
- * @param[in] method The introspected method
  *
- * @since 1.16
+ * @since 1.21
  *
  * @ingroup Eldbus_Model_Method
  */
-EOAPI void eldbus_model_method_constructor(Eo *obj, Eldbus_Proxy *proxy, const Eldbus_Introspection_Method *method);
+EOAPI void eldbus_model_method_proxy_set(Eo *obj, Eldbus_Proxy *proxy);
+
+/**
+ * @brief Object
+ *
+ * @param[in] obj The object.
+ * @param[in] method The introspected interface
+ *
+ * @ingroup Eldbus_Model_Method
+ */
+EOAPI void eldbus_model_method_set(Eo *obj, const Eldbus_Introspection_Method *method);
 
 /**
  * @brief Calls the method. The properties must have been set.
@@ -42,6 +53,8 @@ EOAPI void eldbus_model_method_constructor(Eo *obj, Eldbus_Proxy *proxy, const E
  * The event ELDBUS_MODEL_METHOD_EVENT_METHOD_CALLED is raised for a successful
  * call. Otherwise
  *
+ * @param[in] obj The object.
+ *
  * @since 1.16
  *
  * @ingroup Eldbus_Model_Method
@@ -55,5 +68,6 @@ EWAPI extern const Efl_Event_Description _ELDBUS_MODEL_METHOD_EVENT_SUCCESSFUL_C
  * @ingroup Eldbus_Model_Method
  */
 #define ELDBUS_MODEL_METHOD_EVENT_SUCCESSFUL_CALL (&(_ELDBUS_MODEL_METHOD_EVENT_SUCCESSFUL_CALL))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
