@@ -13,13 +13,14 @@ typedef Eo Eldbus_Model_Object;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Eldbus model object class
  *
  * @ingroup Eldbus_Model_Object
  */
 #define ELDBUS_MODEL_OBJECT_CLASS eldbus_model_object_class_get()
 
-EWAPI const Efl_Class *eldbus_model_object_class_get(void);
+EWAPI const Efl_Class *eldbus_model_object_class_get(void) EINA_CONST;
 
 /**
  * @brief DBus Name or unique-id
@@ -62,5 +63,6 @@ EOAPI void eldbus_model_object_path_set(Eo *obj, const char *path);
  * @ingroup Eldbus_Model_Object
  */
 EOAPI const char *eldbus_model_object_path_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
