@@ -13,12 +13,14 @@ typedef Eo Efl_Ui_Button_Legacy_Part;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Elementary button internal part class
  *
  * @ingroup Efl_Ui_Button_Legacy_Part
  */
 #define EFL_UI_BUTTON_LEGACY_PART_CLASS efl_ui_button_legacy_part_class_get()
 
-EWAPI const Efl_Class *efl_ui_button_legacy_part_class_get(void);
+EWAPI const Efl_Class *efl_ui_button_legacy_part_class_get(void) EINA_CONST;
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
