@@ -32,7 +32,7 @@ typedef Eo Efl_Ui_Grid_View;
  */
 #define EFL_UI_GRID_VIEW_CLASS efl_ui_grid_view_class_get()
 
-EWAPI const Efl_Class *efl_ui_grid_view_class_get(void);
+EWAPI const Efl_Class *efl_ui_grid_view_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
