@@ -13,21 +13,36 @@ typedef Eo Efl_Ui_Layout_Factory;
 
 
 #endif
-/** Efl Ui Layout Factory class
+/**
+ * @brief @ref Efl_Ui_Factory that creates @ref Efl_Ui_Layout objects with
+ * caching.
+ *
+ * This factory is meant to be used by @ref Efl_Ui_View objects that use items
+ * with Layout and need the items to be created, updated, their model set and
+ * connected automatically before the @ref Efl_Ui_View receives the item
+ * instance.
+ *
+ * This class inherits from @ref Efl_Ui_Caching_Factory and inherits all its
+ * properties.
+ *
+ * @since 1.24
  *
  * @ingroup Efl_Ui_Layout_Factory
  */
 #define EFL_UI_LAYOUT_FACTORY_CLASS efl_ui_layout_factory_class_get()
 
-EWAPI const Efl_Class *efl_ui_layout_factory_class_get(void);
+EWAPI const Efl_Class *efl_ui_layout_factory_class_get(void) EINA_CONST;
 
 /**
- * @brief No description supplied.
+ * @brief Set the theme that will be applied to the created @ref Efl_Ui_Layout
+ * objects. See @ref efl_ui_layout_theme_get for more details.
  *
  * @param[in] obj The object.
  * @param[in] klass The class of the group.
  * @param[in] group The group.
- * @param[in] style The style to used.
+ * @param[in] style The style to use.
+ *
+ * @since 1.24
  *
  * @ingroup Efl_Ui_Layout_Factory
  */
