@@ -16,7 +16,7 @@ typedef Eo Efl_Ui_Spotlight_Util;
 #ifdef EFL_BETA_API_SUPPORT
 #define EFL_UI_SPOTLIGHT_UTIL_CLASS efl_ui_spotlight_util_class_get()
 
-EWAPI const Efl_Class *efl_ui_spotlight_util_class_get(void);
+EWAPI const Efl_Class *efl_ui_spotlight_util_class_get(void) EINA_CONST;
 
 /**
  * @brief Get a preconfigured stack obejct
