@@ -40,7 +40,7 @@ typedef enum
  */
 #define EFL_UI_TEXTPATH_CLASS efl_ui_textpath_class_get()
 
-EWAPI const Efl_Class *efl_ui_textpath_class_get(void);
+EWAPI const Efl_Class *efl_ui_textpath_class_get(void) EINA_CONST;
 
 /**
  * @brief Set a circle with given radius and start angle. The center of the
