@@ -13,6 +13,7 @@ typedef Eo Efl_Object_Override;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief A special class to pass to #eo_super() when using #eo_override()
  *
@@ -22,6 +23,7 @@ typedef Eo Efl_Object_Override;
  */
 #define EFL_OBJECT_OVERRIDE_CLASS efl_object_override_class_get()
 
-EWAPI const Efl_Class *efl_object_override_class_get(void);
+EWAPI const Efl_Class *efl_object_override_class_get(void) EINA_CONST;
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
