@@ -28,7 +28,7 @@ typedef Eo Efl_Canvas_Group;
  */
 #define EFL_CANVAS_GROUP_CLASS efl_canvas_group_class_get()
 
-EWAPI const Efl_Class *efl_canvas_group_class_get(void);
+EWAPI const Efl_Class *efl_canvas_group_class_get(void) EINA_CONST;
 
 /**
  * @brief Indicates that the group's layout needs to be recalculated.
@@ -123,7 +123,7 @@ EOAPI void efl_canvas_group_calculate(Eo *obj);
  *
  * @ingroup Efl_Canvas_Group
  */
-EOAPI Eina_Iterator *efl_canvas_group_members_iterate(const Eo *obj);
+EOAPI Eina_Iterator *efl_canvas_group_members_iterate(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Set a canvas object as a member of a given group (or smart object).
@@ -147,7 +147,7 @@ EOAPI Eina_Iterator *efl_canvas_group_members_iterate(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Group
  */
-EOAPI void efl_canvas_group_member_add(Eo *obj, Efl_Canvas_Object *sub_obj) EINA_ARG_NONNULL(2);
+EOAPI void efl_canvas_group_member_add(Eo *obj, Efl_Canvas_Object *sub_obj);
 
 /**
  * @brief Removes a member object from a given smart object.
@@ -189,8 +189,6 @@ EOAPI Eina_Bool efl_canvas_group_member_is(const Eo *obj, const Efl_Canvas_Objec
  * This is the object clipping all the child objects. Do not delete or
  * otherwise modify this clipper!
  *
- * Get the internal clipper.
- *
  * @param[in] obj The object.
  *
  * @return A clipper rectangle.
