@@ -13,6 +13,7 @@ typedef Eo Efl_Canvas_Image;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Low-level Image object.
  *
@@ -24,6 +25,7 @@ typedef Eo Efl_Canvas_Image;
  */
 #define EFL_CANVAS_IMAGE_CLASS efl_canvas_image_class_get()
 
-EWAPI const Efl_Class *efl_canvas_image_class_get(void);
+EWAPI const Efl_Class *efl_canvas_image_class_get(void) EINA_CONST;
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
