@@ -20,7 +20,7 @@ typedef Eo Efl_Canvas_Rectangle;
  */
 #define EFL_CANVAS_RECTANGLE_CLASS efl_canvas_rectangle_class_get()
 
-EWAPI const Efl_Class *efl_canvas_rectangle_class_get(void);
+EWAPI const Efl_Class *efl_canvas_rectangle_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
