@@ -20,7 +20,7 @@ typedef Eo Efl_Canvas_Vg_Container;
  */
 #define EFL_CANVAS_VG_CONTAINER_CLASS efl_canvas_vg_container_class_get()
 
-EWAPI const Efl_Class *efl_canvas_vg_container_class_get(void);
+EWAPI const Efl_Class *efl_canvas_vg_container_class_get(void) EINA_CONST;
 
 /**
  * @brief Get child of container
